/* global angular */
angular.module('app.calendar', [])

//Config block that contains the state declaration
.config(function($stateProvider) {  
  $stateProvider
    .state('app.calendar', {
    url: '/calendar/:challengeID',
    cache: true,
    views: {
      'menuContent': {
        templateUrl: 'app/calendar/calendar.html',
        controller: 'CalendarCtrl'
      }
    }
  });
})

.controller('CalendarCtrl', function($scope, $rootScope, $state, $stateParams, $ionicModal,
  $timeout, ChallengeSrv, $ionicPopup, $cordovaGoogleAnalytics, $ionicScrollDelegate, $ionicLoading, $ionicNativeTransitions) {

  try {
    $cordovaGoogleAnalytics.trackView('Workout Calendar');
  } catch (e) {
    console.error("Error tracking Google cordovaGoogleAnalytics home view");
  }

  // initialize dailiyWorkout calendar on first time load
  $scope.dailyWorkout = [{noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, 
    {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, 
    {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, 
    {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, 
    {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, 
    {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}, 
    {noSticker: true}, {noSticker: true}, {noSticker: true}, {noSticker: true}];

  // show the loading spinner on first time load
  $ionicLoading.show({
    duration: 6000
  });

  $scope.$on('$ionicView.beforeEnter', function(event, viewData) {
    viewData.enableBack = true;

    var message = [
      'Have you hearted yourself today?',
      'Be your own Fit Girl!',
      'You eat obstacles for breakfast!',
      'Your water bottle misses you :(',
      'Fit Girls Don’t Quit!',
      'We are blinded by your fierceness!',
      'Stop drop and dance party!',
      'You’re already fabulous!',
      'Your epicness awaits!'
    ]

    var random =  Math.round(Math.random() * (message.length - 1));
    $scope.motivational = message[random];
  });

  $scope.$on('$ionicView.afterEnter', function(event, viewData) {
    new Parse.Query('Challenge')
    .get($stateParams.challengeID)
    .then(function(challenge){
      $scope.challenge = challenge;
      getWorkout(challenge);
    }, function(err){
      $ionicLoading.hide();
      console.error(JSON.stringify(err));
      if (err.code === 100) {
        $ionicPopup.alert({
          title: "IS YOUR INTERNET ON?",
          subTitle: "You must have a data or wifi connection to view and record your progress :(",
          scope: $scope,
          buttons: [
            {
              text: '<b>Okay</b>',
              type: 'button-calm',
            }
          ]
        });
      }
    });
    
    getWorkout = function(challenge) {
      // obtaining workout through challenge relation
      var workoutRelation = challenge.relation('dailyWorkouts');
      workoutRelation.query().ascending('day').find().then(function(details) {
        $scope.dailyWorkout = details;
        var counter = 0;
        $scope.dailyWorkout.forEach(function(workout) {
          if(workout.has('finished_both') || workout.has('finished_eating') || workout.has('finished_workout') || 
            workout.has('neither') || workout.has('rest_day') || workout.has('sick')) { 
            counter++;
          } 
        });
        $scope.daysLeft = 28 - counter;    
        getStickers(details);
      }, function(err){
        $ionicLoading.hide();
        console.error(err);
      });
    };

    getStickers = function(workoutDetails){
      $scope.dailyWorkout.forEach(function(workout){
        if(workout.attributes.finished_both == true){
          workout.gold = true;
        } else if(workout.attributes.finished_eating == true || workout.attributes.finished_workout == false){
          workout.purple = true;
        } else if(workout.attributes.finished_eating == false || workout.attributes.finished_workout == true){
          workout.purple = true;
        } else if(workout.attributes.sick == true){
          workout.brokenHeart = true;
        } else if(workout.attributes.neither == true || workout.attributes.rest_day == true){
          workout.greyHeart = true;
        } else{
          workout.noSticker = true;
        }
      });
      $ionicLoading.hide();
      $scope.$apply();

      // scroll to the bottom if their calendar is done after half a second
      if ($scope.daysLeft == 0) {
        setTimeout(function() {
          $ionicScrollDelegate.scrollBottom(true);
        }, 500);
      }
    };

  });

  $scope.navigateToWorkoutDetails = function (workout, current) {
    // NOTE: this if statement was commented out to allow a user to edit all days at any time, uncomment to restrict the user.
    // if(current == true){
      $state.go('app.workoutDetails', {id : workout, daysLeft : $scope.daysLeft, challengeID: $scope.challenge.id});
    // }
  };

  $scope.resetCalendar = function() {
    $ionicPopup.show({
      title: 'Reset Calendar',
      subTitle: 'Are you sure you want to reset your challenge tracker? ' + 
        'You\'ll be brought back to the home screen and can start the 28 Day Challenge over again. ',
      cssClass: "popup-vertical-buttons",
      scope: $scope,
      buttons: [
        {
          text: 'Reset',
          type: 'button-calm',
          onTap: function(e) {
            resetCalendar();
          }
        },
        {
          text: 'Cancel',
          type: 'button-stable'
        }
      ]
    });
  }

  function resetCalendar() {
    $rootScope.user.unset('currentChallenge');
    $scope.challenge.set('archiveDate', new Date());
    Parse.Object.saveAll([$rootScope.user, $scope.challenge]).then(function(res) {
      $ionicNativeTransitions.stateGo('app.home', {}, {
        type: 'slide',
        direction: 'right'
      })
    }, function(err) {
      console.error(JSON.stringify(err));
    });
  };

})