angular.module('app.workoutDetails', [])

//Config block that contains the state declaration
.config(function($stateProvider) {  
  $stateProvider
    .state('app.workoutDetails', {
    url: '/workoutDetails/:id/:daysLeft/:challengeID',
    cache: true,
    views: {
      'menuContent': {
        templateUrl: 'app/calendar/workout_details/workout_details.html',
        controller: 'WorkoutDetailsCtrl'
      }
    }
  });
})

.controller('WorkoutDetailsCtrl', function($scope, $rootScope, $state, $stateParams, $ionicModal, $q, $cordovaGoogleAnalytics, $ionicLoading, $ionicNativeTransitions, $timeout, $ionicHistory) {
  console.log("Inside WorkoutDetailsCtrl");

  try {
    $cordovaGoogleAnalytics.trackView('Workout Details');
  } catch (e) {
    console.error("Error tracking Google cordovaGoogleAnalytics home view");
  }

  $scope.$on('$ionicView.beforeEnter', function (event, viewData) {
    $ionicLoading.show();
    viewData.enableBack = true;
    $scope.dailyExercises = [];

    // get specific workout by passed in ID
    new Parse.Query('DailyWorkouts')
    .get($stateParams.id)
    .then(function(dayWorkout) {
      $ionicLoading.hide();
      $scope.workout = dayWorkout;
      // setting remaining days of the challenge through passed in parameters
      $scope.daysLeft = $stateParams.daysLeft;
      if((29 - $scope.daysLeft) == $scope.workout.attributes.day){
        $scope.notCurrentWorkOutDay = false;
      }
      else{
        $scope.notCurrentWorkOutDay = true;
      }
      getWorkoutDetails(dayWorkout);
    }, function(err){
        $ionicLoading.hide();
        console.error(err);
    });

    getWorkoutDetails= function(workout){
      for(x = 0; x < workout.attributes.exercises.length; x++){
        var tmp = workout.attributes.exercises[x];
        $scope.dailyExercises.push(tmp);
      }
      $scope.$apply();
    }

    var message = [
      'Have you hearted yourself today?',
      'Be your own Fit Girl!',
      'You eat obstacles for breakfast!',
      'Your water bottle misses you :(',
      'Fit Girls Don’t Quit!',
      'We are blinded by your fierceness!',
      'Stop drop and dance party!',
      'You’re already fabulous!',
      'Your epicness awaits!'
    ]

    var random =  Math.round(Math.random() * (message.length - 1));
    $scope.motivational = message[random];
  });

  var fireNativeTransition = function(direction, cb) {
    if ($scope.transitionTimeout) return;
    $scope.transitionTimeout = $timeout(function(){
      window.plugins.nativepagetransitions.executePendingTransition();
      $scope.transitionTimeout = null
      if (cb) { cb(); }
    }, 300);
    window.plugins.nativepagetransitions.slide({direction: direction});
  }
  
  $scope.openResultsModal = function () {
    $ionicLoading.show({
      duration: 1000
    });
    $ionicModal.fromTemplateUrl('app/calendar/workout_details/resultsModal.html', {
      scope: $scope,
      animation: 'none'
    }).then(function(modal) {
      $scope.modal = modal;
      fireNativeTransition("up", function() {
        $scope.modal.show();
      });
    });
  };

  $scope.closeModal = function () {
    fireNativeTransition("down");
    $scope.modal.remove();
  };

  $scope.setProgressChoice = function() {
    if (!$scope.workoutValue) {
      $scope.closeModal();
    }
    new Parse.Query('DailyWorkouts').get($scope.workout.id).then(function(progress) {
      if ($scope.workoutValue == 'workout') {
        $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout');
        progress.set('finished_workout', true);
        progress.unset('finished_eating');
        progress.unset('finished_both');
        progress.unset('neither');
        progress.unset('sick');
        progress.unset('rest_day');
        progress.save();
        if (progress.attributes.day === 28) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout, 28 days');
          $scope.goToMotivation('youdidit');
        } else if (progress.attributes.day === 7) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout, Week 1');
          $scope.goToMotivation('weekone');
        } else if (progress.attributes.day === 14) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout, Week 2');
          $scope.goToMotivation('weektwo');
        } else if (progress.attributes.day === 21) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout, Week 3');
          $scope.goToMotivation('weekthree');
        } else {
          $scope.goToMotivation('progress');
        }
      } else if ($scope.workoutValue == 'eating') {
        $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Eating');
        progress.unset('finished_workout');
        progress.set('finished_eating', true);
        progress.unset('finished_both');
        progress.unset('neither');
        progress.unset('sick');
        progress.unset('rest_day');
        progress.save();
        if (progress.attributes.day === 28){
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Eating, 28 days');
          $scope.goToMotivation('youdidit');
        } else if (progress.attributes.day === 7) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Eating, Week 1');
          $scope.goToMotivation('weekone');
        } else if (progress.attributes.day === 14) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Eating, Week 2');
          $scope.goToMotivation('weektwo');
        } else if (progress.attributes.day === 21) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Eating, Week 3');
          $scope.goToMotivation('weekthree');
        } else {
          $scope.goToMotivation('progress');
        }
      } else if($scope.workoutValue == 'both') {
        $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout + Eating');
        progress.unset('finished_workout');
        progress.unset('finished_eating');
        progress.set('finished_both', true);
        progress.unset('neither');
        progress.unset('sick');
        progress.unset('rest_day');
        progress.save();
        if (progress.attributes.day === 28){
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout + Eating, 28 days');
          $scope.goToMotivation('youdidit');
        } else if (progress.attributes.day === 7) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout + Eating, Week 1');
          $scope.goToMotivation('weekone');
        } else if (progress.attributes.day === 14) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout + Eating, Week 2');
          $scope.goToMotivation('weektwo');
        } else if (progress.attributes.day === 21) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Workout + Eating, Week 3');
          $scope.goToMotivation('weekthree');
        } else {
          $scope.goToMotivation('yourock');
        }
      } else if($scope.workoutValue == 'neither') {
        $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Neither');
        progress.unset('finished_workout');
        progress.unset('finished_eating');
        progress.unset('finished_both');
        progress.set('neither', true);
        progress.unset('sick');
        progress.unset('rest_day');
        progress.save();
        if (progress.attributes.day === 28){
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Neither, 28 days');
          $scope.goToMotivation('youdidit');
        } else if (progress.attributes.day === 7) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Neither, Week 1');
          $scope.goToMotivation('weekone');
        } else if (progress.attributes.day === 14) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Neither, Week 2');
          $scope.goToMotivation('weektwo');
        } else if (progress.attributes.day === 21) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Neither, Week 3');
          $scope.goToMotivation('weekthree');
        } else {
          $scope.goToMotivation('dontquit');
        }
      } else if($scope.workoutValue == 'sick') {
        $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Sick or Injured');
        progress.unset('finished_workout');
        progress.unset('finished_eating');
        progress.unset('finished_both');
        progress.unset('neither');
        progress.set('sick', true);
        progress.unset('rest_day');
        progress.save();
        if (progress.attributes.day === 28){
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Sick or Injured, 28 days');
          $scope.goToMotivation('youdidit');
        } else if (progress.attributes.day === 7) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Sick or Injured, Week 1');
          $scope.goToMotivation('weekone');
        } else if (progress.attributes.day === 14) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Sick or Injured, Week 2');
          $scope.goToMotivation('weektwo');
        } else if (progress.attributes.day === 21) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Sick or Injured, Week 3');
          $scope.goToMotivation('weekthree');
        } else {
          $scope.goToMotivation('feelbetter');
        }
      } else if ($scope.workoutValue == 'rest') {
        $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Rest Day');
        progress.unset('finished_workout');
        progress.unset('finished_eating');
        progress.unset('finished_both');
        progress.unset('neither');
        progress.unset('sick');
        progress.set('rest_day', true);
        progress.save();
        if (progress.attributes.day === 28){
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Rest Day, 28 days');
          $scope.goToMotivation('youdidit');
        } else if (progress.attributes.day === 7) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Rest Day, Week 1');
          $scope.goToMotivation('weekone');
        } else if (progress.attributes.day === 14) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Rest Day, Week 2');
          $scope.goToMotivation('weektwo');
        } else if (progress.attributes.day === 21) {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Rest Day, Week 3');
          $scope.goToMotivation('weekthree');
        } else {
          $cordovaGoogleAnalytics.trackEvent('Workout Tracker', 'User selected Rest Day');
          $scope.goToMotivation('rest');
        }
      }
    }, function(err) {
      console.error(JSON.stringify(err));
    });
  };

  $scope.dayProgress = function(status){
    // set selected modal value on $scope.workout tracker
    $scope.workoutValue = status;
  };

  $scope.goToMotivation = function(type) {
    // clear workoutValue
    // this is the exit of all setProgressChoice clauses, so the line is placed here for convenience ONLY
    $scope.workoutValue = null;

    $ionicHistory.nextViewOptions({
      disableBack: true
    });

    $ionicNativeTransitions.stateGo('app.motivationalPage', 
      { message: type, challengeID: $stateParams.challengeID }, 
      { type: 'slide', direction:'up'}
    );
    // remove the modal way down here so that it's removed AFTER the page transition starts
    $scope.modal.remove();
  };
})