angular.module('app.home', [])

//Config block that contains the state declaration
.config(function($stateProvider) {  
  $stateProvider
    .state('app.home', {
    url: '/home',
    views: {
      'menuContent': {
        templateUrl: 'app/home/home.html',
        controller: 'HomeCtrl'
      }
    }
  });
})

.controller('HomeCtrl', function($scope, $rootScope, $state, $ionicModal, $ionicLoading, $timeout, 
  $ionicPopup, $cordovaGoogleAnalytics, PushSrv, AddWorkoutsSrv) {
  console.log("Inside HomeCtrl");

  $scope.$on('$ionicView.enter', function () {
    try {
      $cordovaGoogleAnalytics.trackView('Home');
    } catch (e) {
      console.error("Error tracking Google cordovaGoogleAnalytics home view");
    }
  });

  $scope.goToChallenges = function () {
    $ionicLoading.show({
      hideOnStateChange: true
    });
    try {
      $cordovaGoogleAnalytics.trackEvent('Home', 'Click Challenges');
    } catch (e) {
      console.error("Error tracking Google cordovaGoogleAnalytics Home --> Challenges");
    }
    if ($rootScope.user.has('currentChallenge')) {
      console.log('user already has a challenge, going to the calendar');
      console.log($rootScope.user.get('currentChallenge').id);
      $state.go('app.calendar', { challengeID : $rootScope.user.get('currentChallenge').id });
      return;
    }
    // OLD TO NEW ARCHITECTURAL MIGRATION
    // Check if the user currently has any challenges that do not have a 'archiveDate' field set
    $rootScope.user.relation('Challenges').query()
    .doesNotExist('archiveDate').find().then(function(res) {
      // if none, create their challenge, the function auto adds it to their 'currentChallenge' ptr
      if (!res.length) {
        $ionicLoading.hide();
        startChallenge();
        return;
      }
      // else they are a LEGACY USER, add their only challenge to their currentChallenge
      $rootScope.user.set('currentChallenge', res[0]);
      $rootScope.user.save();
      $state.go('app.calendar', { challengeID : res[0].id });
    }, function(err) {
      console.error(JSON.stringify(err));
    });
  };

  $scope.goToEbook = function () {
    try {
      $cordovaGoogleAnalytics.trackEvent('Home', 'Click Preview');
    } catch (e) {
      console.error("Error tracking Google cordovaGoogleAnalytics Home --> EBook");
    }
    console.log('Go To Preview CLICKED!');
    $state.go('app.preview');
  };

  $scope.goToProfile = function () {
    try {
      $cordovaGoogleAnalytics.trackEvent('Home', 'Click profile');
    } catch (e) {
      console.error("Error tracking Google cordovaGoogleAnalytics Home --> Profile");
    }
    console.log('Go To Profile CLICKED!');
    $state.go('app.profile');
  };

  startChallenge = function() {
    var myPopup = $ionicPopup.show({
      title: 'START YOUR CHALLENGE!',
      subTitle: "By clicking \"Start Now!\" you will begin your 28 Day Jumpstart fitventure! See page 72 in the book for full directions on how to do the workouts. And don't forget that following the Jumpstart eating guidelines is THE key to getting results. The Meal Plans begin on page 112! Above all, never give up on yourself. Progress not perfection. Fit Girls Don't Quit! #bicepemoji",
      cssClass: "popup-vertical-buttons",
      buttons: [
        { text: 'Cancel',
          type: 'button-stable',
          onTap:function(e){
            $state.go('app.home');
          }
        },
        {
          text: '<b>LEARN MORE</b>',
          type: 'button-energized',
          onTap: function(e) {
            $state.go('app.conclusion');
          }    
        },
        {
          text: '<b>START NOW!</b>',
          type: 'button-calm',
          onTap: function(e) {
            $ionicLoading.show({
              hideOnStateChange: true
            });
            AddWorkoutsSrv.add28DayWorkout().then(function(newChallenge) {
              $state.go('app.calendar', { challengeID : newChallenge.id });
            }, function(err) {
              $ionicLoading.hide();
              console.error('Error Creating New 28 Day Challenge: ', JSON.stringify(err));
            });         
          }
      }]
    })
  };
})