angular.module('app.login', [])

//Config block that contains the state declaration
.config(function($stateProvider) {  
  $stateProvider
    .state('app.login', {
    url: '/login',
    cache: false,
    views: {
      'menuContent': {
        templateUrl: 'app/login/login.html',
        controller: 'LoginCtrl'
      }
    }
  });
})

.controller('LoginCtrl', function($scope, $rootScope, $state, $ionicModal, $ionicLoading, 
  $timeout, $ionicPopup, $cordovaGoogleAnalytics, ngFB, AddWorkoutsSrv, FaceBookConnectSrv, PushSrv, $ionicHistory) {

  console.log("Inside LoginCtrl");

  $scope.user = {};
  $scope.error = {};
  $scope.error.message = {};

  try {
    $cordovaGoogleAnalytics.trackView('Login');
  } catch (e) {
    console.error("Error tracking Google cordovaGoogleAnalytics home view");
  }

  // Create the login modal that we will use later
  $ionicModal.fromTemplateUrl('app/login/login.html', {
    scope: $scope
  }).then(function(modal) {
    $scope.modal = modal;
  });

  // Triggered in the login modal to close it
  $scope.closeLogin = function() {
    $scope.modal.hide();
    $state.go('app.welcome');
  };

  // Open the login modal
  $scope.login = function() {
    $scope.modal.show();
  };

  // Perform the login action when the user submits the login form
  $scope.doLogin = function() {
    try {
      $cordovaGoogleAnalytics.trackEvent('Login', 'User Clicked Login');
    } catch (e) {
      console.error("Error tracking Google cordovaGoogleAnalytics Login Click");
    }
    $scope.loading = $ionicLoading.show({
      content: 'Logging In ...',
      animation: 'fade-in',
      showBackdrop: true,
      maxWidth: 200,
      showDelay: 0
    });

    Parse.User.logIn($scope.user.username, $scope.user.password,{

      success:function(_user){
        console.log('Successfully Logged In');
        if(_user.get('emailVerified')){
          console.log('Login / Email is verified');
          $rootScope.user = _user;
          $rootScope.isLoggedIn = true;
          $ionicLoading.hide();
          PushSrv.register();

          $ionicHistory.nextViewOptions({
            historyRoot: true
          })

          $state.go('app.home');
        }
        else{
          console.log('Email is not verified');
          $ionicLoading.hide();
          $scope.error.message = ('The email to this account has not been verified.');
        }
      },
      error: function(_user, error){
        console.error('Parse.User.logIn error user id: ', JSON.stringify(error));
        $ionicLoading.hide();
        $scope.user = _user;
        if (error.code === 201) {
          $scope.error.message = ("Whoops! Please enter a password.");
        } else if (error.code === 200) {
          $scope.error.message = ("Oh no! Please enter an email address.");
        } else if (error.code === 101) {
          $scope.error.message = ("Uh-oh! Please check the email and password combination you entered.");
        } else {
          $scope.error.message = ("Something is up here ... Please try again.");
        }
      }
    });

    // Simulate a login delay. Remove this and replace with your login
    // code if using a login system
    $timeout(function() {
      $scope.modal.hide();
    }, 1000);
  };

  $scope.fbLogin = function () {
    try {
      $cordovaGoogleAnalytics.trackEvent('Login', 'User Clicked Facebook Login');
    } catch (e) {
      console.error("Error tracking Google cordovaGoogleAnalytics Facebook Login");
    }
    ngFB.login({scope: 'email,public_profile'}).then(
      function (response) {
        if (response.status === 'connected') {
          FaceBookConnectSrv.getFBUserDetails();

          $ionicLoading.show({
            template: '<h2>Logging in...</h2>',
            duration: 3000,
            noBackdrop: true,
            hideOnStateChange: true
          });

          console.log('Facebook login succeeded');
          $scope.modal.hide();
        } else {
          $ionicPopup.alert({
            title: "Something went wrong!",
            subTitle: "We could not connect to your facebook.  Please try again!",
            scope: $scope,
            buttons: [
              {
                text: '<b>Okay</b>',
                type: 'button-calm',
              }
            ]
          }); 
        }
    });
  };

  $scope.forgotPwd = function(){
    console.log("forgot password was clicked");
    $scope.closeLogin();
    $state.go('app.forgotpwd');
  }
})