angular.module('app.profile', [])

//Config block that contains the state declaration
.config(function($stateProvider) {  
  $stateProvider
    .state('app.profile', {
    url: '/profile',
    cache: false,
    views: {
      'menuContent': {
        templateUrl: 'app/profile/profile.html',
        controller: 'ProfileCtrl'
      }
    }
  });
})

.controller('ProfileCtrl', function($scope, $rootScope, $state, $ionicModal, $ionicLoading, $ionicPopup, 
  $timeout, $cordovaCamera, ngFB, moment, $cordovaDatePicker, $cordovaGoogleAnalytics, $ionicHistory) {
  console.log("Inside ProfileCtrl");

  try {
    $cordovaGoogleAnalytics.trackView('Profile');
  } catch (e) {
    console.error("Error tracking Google cordovaGoogleAnalytics Profile View");
  }

  $scope.$on('$ionicView.beforeEnter', function(state, viewData) {
    viewData.enableBack = true;
    
    angular.extend($scope, {
      user: $rootScope.user,
      moment: moment,
      data: {
        weight: { weight: $rootScope.user.has('weight') ? $rootScope.user.get('weight') : undefined },
        height: { height: $rootScope.user.has('height') ? $rootScope.user.get('height') : undefined },
        dobDisplay: $rootScope.user.has('DOB') ? moment($rootScope.user.get('DOB')).format('MMMM Do YYYY') : undefined,
        dateJoinedDisplay: $rootScope.user.has('dateJoined') ? moment($rootScope.user.get('dateJoined')).format('MMMM Do YYYY') : undefined,
      },
      error: {},
      edit: false,
      weightValues: [],
      heightValues: []
    });

    //Obtain height values
    $scope.heightNumbers = ["4'0", "4'1", "4'2", "4'3", "4'4", "4'5", "4'6", "4'7", "4'8", "4'9", "4'10", "4'11",
    "5'0", "5'1", "5'2", "5'3", "5'4", "5'5", "5'6", "5'7", "5'8", "5'9", "5'10", "5'11",
    "6'0", "6'1", "6'2", "6'3", "6'4", "6'5", "6'6", "6'7", "6'8", "6'9", "6'10", "6'11", "7'0"];

    for(x=0; $scope.heightNumbers.length > x; x++){
      var height = $scope.heightNumbers[x].toString();
      height = height + '\"';
      var tmp = {'height': height, 'number': x};
      $scope.heightValues.push(tmp);
    }

    //Obtain weight values
    for(x = 80; x < 401; x++){
      var tmp = {'weight': x};
      $scope.weightValues.push(tmp);
    }

    if($rootScope.user.has('dateJoined')){
      var currentDay = moment();
      var dateJoined = moment($rootScope.user.get('dateJoined'));
      $scope.numberOfDays = currentDay.diff(dateJoined, 'days');
    }
  });

  $scope.saveButtonDisable = function () {
    $scope.disableSave = true;
  }

  $scope.saveButtonEnable = function () {
    $scope.disableSave = false;
  }

  $scope.editProfile = function () {
    try {
      $cordovaGoogleAnalytics.trackEvent('Profile', 'User Clicked Edit Profile');
    } catch (e) {}
    $scope.edit = true;
  };

  $scope.pickDate = function (field) {
    $cordovaDatePicker.show({
      date: new Date(),
      mode: 'date'
    }).then(function(date) {
      console.log(date);
      if (field === 'dateJoined') {
        try {
          $cordovaGoogleAnalytics.trackEvent('Profile', 'User Edited Date Joined');
        } catch(e) {}
        $scope.data.dateJoined = date;
        $scope.data.dateJoinedDisplay = moment(date).format('MMMM Do YYYY');
      }
      if (field === 'dob') {
        try {
          $cordovaGoogleAnalytics.trackEvent('Profile', 'User Edited DOB');
        } catch (e) {}
        $scope.data.dob = date;
        $scope.data.dobDisplay = moment(date).format('MMMM Do YYYY');
      }
      $timeout();
    }, function(err) {
      console.error(JSON.stringify(err));
    });
  };

  $scope.changePhoto = function () {  
    $ionicPopup.show({ 
      // title: title,
      subTitle: 'Would you like to take a new pic or upload an existing photo?',
      cssClass: "popup-vertical-buttons",
      scope: $scope,
      buttons: [
        { text: 'New',
        type: 'button-calm',
        onTap: function(e) {
          try {
            $cordovaGoogleAnalytics.trackEvent('Profile', 'User Uploaded New Photo');
          } catch (e) {}
          var options = {
            quality: 80,
            destinationType: Camera.DestinationType.DATA_URL,
            sourceType: Camera.PictureSourceType.CAMERA,
            allowEdit: true,
            encodingType: Camera.EncodingType.JPEG,
            popoverOptions: CameraPopoverOptions,
            saveToPhotoAlbum: false,
            correctOrientation: true,
            targetWidth: 150,
            targetHeight: 150
          };
          uploadPicture(options);
        }
      },
      {
        text: 'Upload',
        type: 'button-calm',
        onTap: function(e) {
          try {
            $cordovaGoogleAnalytics.trackEvent('Profile', 'User Uploaded Existing Photo');
          } catch (e) {}
          var options = {
            quality: 80, 
            destinationType: navigator.camera.DestinationType.DATA_URL, 
            sourceType: navigator.camera.PictureSourceType.PHOTOLIBRARY,
            allowEdit: true,
            correctOrientation: true,
            targetWidth: 150,
            targetHeight: 150
          };
          uploadPicture(options);
        }
      }, 
      {
        text: 'Cancel',
        type: 'button-stable',
        onTap: function(e) {
          return;
        }      
      }]
    });
  }

  function uploadPicture (options) {
    var self = this;
    $cordovaCamera.getPicture(options).then(function(imageData) {
      var Parsefile = new Parse.File('photo.jpg', { base64: imageData });
      $ionicLoading.show({
        template: 'Uploading Photo...',
        noBackdrop: true,
        duration: 3000
      });
      return Parsefile.save();
    }).then(function(parseFile) {
      console.log('saved the parse file successfully');
      $rootScope.user.set('profilePhoto', parseFile);
      return $rootScope.user.save();
    }).then(function(user) {
      $rootScope.user = user;
      //$state.go($state.current, {}, { reload: true });
      $ionicLoading.hide();
    }, function (err) {
      $ionicLoading.hide();
      $ionicPopup.alert({
        title: "Something went wrong!",
        subTitle: "We could not upload your photo.  Please try again!",
        scope: $scope,
        buttons: [
          {
            text: '<b>Okay</b>',
            type: 'button-calm',
          }
        ]
      });
    });
  };

  $scope.saveProfile = function () {
    console.log('Save profile was clicked!');
    try {
      $cordovaGoogleAnalytics.trackEvent('Profile', 'User Clicked Save');
    } catch (e) {}

    console.log('firstName', $scope.data.firstName);
    console.log('lastName', $scope.data.lastName);
    console.log('email', $scope.data.email);
    console.log('phone', $scope.data.phone);
    console.log('DOB', $scope.data.dob);
    console.log('dateJoined', $scope.data.dateJoined);
    console.log('height', $scope.data.height);
    console.log('weight', $scope.data.weight);

    if ($rootScope.user.get('firstName') !== $scope.data.firstName && $scope.data.firstName != undefined) {
      $rootScope.user.set('firstName', $scope.data.firstName);
    }

    if ($rootScope.user.get('lastName') !== $scope.data.lastName && $scope.data.lastName != undefined) {
      $rootScope.user.set('lastName', $scope.data.lastName);
    }

    if ($rootScope.user.getEmail() !== $scope.data.email && $scope.data.email) {
      $rootScope.user.set('email', $scope.data.email);
    }

    if ($rootScope.user.get('phone') !== $scope.data.phone && $scope.data.phone != undefined) {
      $rootScope.user.set('phone', $scope.data.phone);
    }

    if ($rootScope.user.get('DOB') !== $scope.data.dob && $scope.data.dob != undefined) {
      if (moment($scope.data.dob).isAfter(moment())) {
        $ionicPopup.show({
          title: 'Are you from the future?',
          subTitle: 'Please pick a date of birth in the past',
          cssClass: "popup-vertical-buttons",
          buttons: [
          { text: 'Okay',
            type: 'button-energized'
          }]
        });
        return;
      }
      $rootScope.user.set('DOB', $scope.data.dob);
    }

    if ($rootScope.user.get('dateJoined') !== $scope.data.dateJoined && $scope.data.dateJoined != undefined) {
      if (moment($scope.data.dateJoined).isAfter(moment())) {
        $ionicPopup.show({
          title: 'Future join date',
          subTitle: 'Please pick a join date in the past',
          cssClass: "popup-vertical-buttons",
          buttons: [
          { text: 'Okay',
            type: 'button-energized'
          }]
        });
        return;
      }
      $rootScope.user.set('dateJoined', $scope.data.dateJoined);
      var currentDay = moment();
      var dateJoined = moment($rootScope.user.get('dateJoined'));
      $scope.numberOfDays = currentDay.diff(dateJoined, 'days');
    }

    if ($rootScope.user.get('height') !== $scope.data.height && $scope.data.height != undefined) {
      $rootScope.user.set('height', $scope.data.height.height);
    }

    if ($rootScope.user.get('weight') !== $scope.data.weight && $scope.data.weight != undefined) {
      $rootScope.user.set('weight', $scope.data.weight.weight);
    }

    $ionicLoading.show({
      duration: 3000,
      noBackdrop: false,
      template: '<h3>Saving Profile</h3>'
    });

    $rootScope.user.save().then(function(user) {
      $ionicLoading.hide();
      $rootScope.user = user;
      angular.extend($scope, {
        user: user,
        edit: false,
        data: {
          weight: { weight: $rootScope.user.has('weight') ? $rootScope.user.get('weight') : undefined },
          height: { height: $rootScope.user.has('height') ? $rootScope.user.get('height') : undefined },
          dobDisplay: $rootScope.user.has('DOB') ? moment($rootScope.user.get('DOB')).format('MMMM Do YYYY') : undefined,
          dateJoinedDisplay: $rootScope.user.has('dateJoined') ? moment($rootScope.user.get('dateJoined')).format('MMMM Do YYYY') : undefined,
        },
        error: {}
      });
      $ionicLoading.show({
        duration: 1250,
        noBackdrop: false,
        template: '<h3>Saved Successfully</h3>'
      });
    }, function(err) {
      $ionicLoading.hide();
      console.error(JSON.stringify(err));
    });
  };

  $scope.logout = function () {
    console.log('Logout was clicked!');
    try {
      $cordovaGoogleAnalytics.trackEvent('Profile', 'User Clicked Log Out');
    } catch (e) {}

    if ($rootScope.isLoggedIn) {
      Parse.User.logOut();
      console.log("After Parse.User.logOut");
      $rootScope.user = null;
      $rootScope.isLoggedIn = false;
      Ionic.Auth.logout();

      $ionicHistory.nextViewOptions({ historyRoot: true });

      $state.go('app.welcome');
    }
  };

})
